pub struct ScriptStack { /* private fields */ }Expand description
Minimal stack abstraction used by the interpreter.
Implementations
Sourceimpl ScriptStack
impl ScriptStack
Sourcepub fn from_items(items: Vec<Vec<u8>>) -> Result<Self, ScriptError>
pub fn from_items(items: Vec<Vec<u8>>) -> Result<Self, ScriptError>
Builds a stack from raw items after enforcing script-element limits.
Sourcepub fn push(&mut self, data: Vec<u8>) -> Result<(), ScriptError>
pub fn push(&mut self, data: Vec<u8>) -> Result<(), ScriptError>
Pushes a raw stack element after enforcing the script-element limit.
Sourcepub fn push_bool(&mut self, value: bool) -> Result<(), ScriptError>
pub fn push_bool(&mut self, value: bool) -> Result<(), ScriptError>
Pushes the canonical boolean stack encoding.