pub enum ScriptError {
Show 39 variants
Ok,
Unknown,
EvalFalse,
OpReturn,
ScriptSize,
PushSize,
OpCount,
StackSize,
SigCount,
PubkeyCount,
Verify,
EqualVerify,
CheckSigVerify,
CheckMultiSigVerify,
NumEqualVerify,
BadOpcode,
OpCodeSeparator,
DisabledOpcode,
InvalidStackOperation,
InvalidAltstackOperation,
UnbalancedConditional,
NegativeLockTime,
UnsatisfiedLockTime,
SigHashType,
MinimalData,
SigPushOnly,
SigNullDummy,
CleanStack,
MinimalIf,
NullFail,
DiscourageUpgradableNops,
DiscourageUpgradableWitnessProgram,
WitnessProgramWrongLength,
WitnessProgramWitnessEmpty,
WitnessProgramMismatch,
WitnessMalleated,
WitnessMalleatedP2SH,
WitnessUnexpected,
SigFindAndDelete,
}Expand description
Script validation errors produced by the Tidecoin validation engine.
Variants
Ok
Default value used before script execution sets a more specific error.
Unknown
Generic script failure when no more specific code is available.
EvalFalse
Script evaluation left a false top stack item.
OpReturn
OP_RETURN aborted script execution.
ScriptSize
Script exceeded the maximum allowed byte size.
PushSize
A pushed element exceeded the maximum allowed byte size.
OpCount
Script exceeded the maximum allowed opcode count.
StackSize
Script exceeded the maximum allowed stack size.
SigCount
Multisig signature count was invalid.
PubkeyCount
Multisig public-key count was invalid.
Verify
OP_VERIFY failed.
EqualVerify
OP_EQUALVERIFY failed.
CheckSigVerify
OP_CHECKSIGVERIFY failed.
CheckMultiSigVerify
OP_CHECKMULTISIGVERIFY failed.
NumEqualVerify
OP_NUMEQUALVERIFY failed.
BadOpcode
Script contained an invalid opcode.
OpCodeSeparator
OP_CODESEPARATOR was disallowed by the active flags.
DisabledOpcode
Script used a disabled opcode.
InvalidStackOperation
Script attempted an invalid main-stack operation.
InvalidAltstackOperation
Script attempted an invalid alt-stack operation.
UnbalancedConditional
Script conditionals were unbalanced.
NegativeLockTime
Locktime argument was negative.
UnsatisfiedLockTime
Locktime requirement was not satisfied.
SigHashType
Signature hash type was invalid for the current validation path.
MinimalData
Non-minimal pushdata encoding was used when forbidden.
SigPushOnly
scriptSig was not push-only when required.
SigNullDummy
Dummy stack argument for multisig was not null.
CleanStack
Cleanstack rule was violated.
MinimalIf
MINIMALIF rule was violated.
NullFail
NULLFAIL rule was violated.
DiscourageUpgradableNops
Upgradable NOPs were discouraged and encountered.
DiscourageUpgradableWitnessProgram
Upgradable witness programs were discouraged and encountered.
WitnessProgramWrongLength
Witness program length did not match the expected form.
WitnessProgramWitnessEmpty
Witness program required witness items but found none.
WitnessProgramMismatch
Witness program did not match the executed witness script.
WitnessMalleated
Native witness spend was malleated.
WitnessMalleatedP2SH
P2SH-wrapped witness spend was malleated.
WitnessUnexpected
Unexpected witness data was present.
SigFindAndDelete
Signature find-and-delete was disallowed by the active flags.